==> hpijs-1.1.tar.gz: hpijs-1.1/dj350.h <==
/*****************************************************************************\
  dj350.h : Interface for the DJ350 class

  Copyright (c) 1996 - 2001, Hewlett-Packard Co.
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of Hewlett-Packard nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
  NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
  TO, PATENT INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\*****************************************************************************/


#ifndef DJ350_H
#define DJ350_H

APDK_BEGIN_NAMESPACE

extern char *ModelString[MAX_ID_STRING];

/*!
\internal
*/
class DJ350 : public DJ600 // Printer
{
public:
    DJ350(SystemServices* pSS,int numfonts=0, BOOL proto=FALSE);

    virtual Header* SelectHeader(PrintContext* pc);


protected:


}; //DJ350

/*
class Mode350Color : public PrintMode
{
public:
    Mode350Color ();
};

*/

#if 0

class Mode350KPhoto : public PrintMode
{
    public:
        Mode350KPhoto (unsigned long *map);
}; //Mode350KPhoto


class Mode350CPhoto : public PrintMode
{
    public:
        Mode350CPhoto (unsigned long *map);
}; //Mode350CPhoto

#endif

#ifdef APDK_PROTO
extern PEN_TYPE ProtoPenType;
/*!
\internal
*/
class ProtoDJ350 : public DJ350
{
public:
    ProtoDJ350(ProtoServices* pSS);

  //  DRIVER_ERROR ParsePenInfo(PEN_TYPE& ePen) { ePen=ProtoPenType; return NO_ERROR; }

}; //ProtoDJ350


#endif

APDK_END_NAMESPACE

#endif

==> hpijs-1.3.1.tar.gz: hpijs-1.3.1/dj350.h <==
/*****************************************************************************\
  dj350.h : Interface for the DJ350 class

  Copyright (c) 1996 - 2001, Hewlett-Packard Co.
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of Hewlett-Packard nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
  NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
  TO, PATENT INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\*****************************************************************************/


#ifndef DJ350_H
#define DJ350_H

APDK_BEGIN_NAMESPACE

extern char *ModelString[MAX_ID_STRING];

/*!
\internal
*/
class DJ350 : public DJ600 // Printer
{
public:
    DJ350(SystemServices* pSS,int numfonts=0, BOOL proto=FALSE);

    virtual Header* SelectHeader(PrintContext* pc);


protected:


}; //DJ350

/*
class Mode350Color : public PrintMode
{
public:
    Mode350Color ();
};

*/

#if 0

class Mode350KPhoto : public PrintMode
{
    public:
        Mode350KPhoto (uint32_t *map);
}; //Mode350KPhoto


class Mode350CPhoto : public PrintMode
{
    public:
        Mode350CPhoto (uint32_t *map);
}; //Mode350CPhoto

#endif

#ifdef APDK_PROTO
extern PEN_TYPE ProtoPenType;
/*!
\internal
*/
class ProtoDJ350 : public DJ350
{
public:
    ProtoDJ350(ProtoServices* pSS);

  //  DRIVER_ERROR ParsePenInfo(PEN_TYPE& ePen) { ePen=ProtoPenType; return NO_ERROR; }

}; //ProtoDJ350


#endif

APDK_END_NAMESPACE

#endif
